<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="14"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>輕量級檔案管理程式</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="87"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;https://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../about.ui" line="78"/>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="100"/>
        <source>License</source>
        <translation>授權</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="109"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>插入可移除式裝置</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;插入可移除式裝置&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>媒體種類:</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>正在偵測...</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>請選擇想要執行的動作:</translation>
    </message>
</context>
<context>
    <name>BulkRenameDialog</name>
    <message>
        <location filename="../../bulk-rename.ui" line="6"/>
        <source>Bulk Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../bulk-rename.ui" line="48"/>
        <source># will be replaced by numbers starting with:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../bulk-rename.ui" line="71"/>
        <source>Rename selected files to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../bulk-rename.ui" line="84"/>
        <source>Name#</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation>連線到遠端伺服器</translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="23"/>
        <source>Anonymous &amp;login</source>
        <translation>匿名登入 (&amp;L)</translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="36"/>
        <source>Login as &amp;user:</source>
        <translation>以使用者名稱登入 (&amp;U):</translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="65"/>
        <source>Specify remote folder to connect</source>
        <translation>指定要連線的遠端目錄</translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="72"/>
        <source>Type:</source>
        <translation>型態:</translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="79"/>
        <source>Port:</source>
        <translation>連接埠:</translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="86"/>
        <source>Path:</source>
        <translation>路徑:</translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="96"/>
        <source>Host:</source>
        <translation>主機:</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>桌面資料夾:</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>影像檔案</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>資料夾路徑</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>瀏覽(&amp;B)</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>桌面偏好設定</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="30"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="52"/>
        <source>Wallpaper mode:</source>
        <translation>桌布:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="65"/>
        <source>Wallpaper image file:</source>
        <translation>桌布影像檔案:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="85"/>
        <source>Select background color:</source>
        <translation>選擇背景顏色:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="94"/>
        <source>Image file</source>
        <translation>影像檔案</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="100"/>
        <source>Image file path</source>
        <translation>影像檔路徑</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="107"/>
        <source>&amp;Browse</source>
        <translation>瀏覽(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="119"/>
        <source>Icons</source>
        <translation>圖示</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="125"/>
        <source>Icon size:</source>
        <translation>圖示大小:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="138"/>
        <source>Label Text</source>
        <translation>標籤文字</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="176"/>
        <source>Select  text color:</source>
        <translation>選擇文字顏色:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="189"/>
        <source>Select shadow color:</source>
        <translation>選擇陰影顏色:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="202"/>
        <source>Select font:</source>
        <translation>選擇字型:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="225"/>
        <source>Spacing</source>
        <translation>間距</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="231"/>
        <source>Minimum item margins:</source>
        <translation>項目邊緣留空:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="238"/>
        <source>3 px by default.</source>
        <translation>預設 3 像素</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="241"/>
        <location filename="../../desktop-preferences.ui" line="265"/>
        <source> px</source>
        <translation> 像素</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="254"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="261"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>預設 1 像素
還會額外保留三行文字高度的空間</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="278"/>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="315"/>
        <source>Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="321"/>
        <source>Enable Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="333"/>
        <source>Wallpaper image folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="340"/>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="347"/>
        <source> hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="357"/>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="370"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="373"/>
        <source>Interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="380"/>
        <source> minute(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="406"/>
        <source>Wallpaper folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="429"/>
        <source>Randomize the slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="459"/>
        <source>Window Manager</source>
        <translation>視窗管理員</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="465"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>按下桌面時顯示視窗管理員提供的選單</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="453"/>
        <source>Advanced</source>
        <translation>進階</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>檔案管理程式</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="301"/>
        <source>Go Up</source>
        <translation>往上一層</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="304"/>
        <source>Alt+Up</source>
        <translation></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="vanished">家目錄</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="316"/>
        <source>Alt+Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="432"/>
        <source>Reload</source>
        <translation>重新讀取</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="328"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="90"/>
        <source>Focus with Ctrl+I</source>
        <translation>以 Ctrl+I 取得焦點</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="178"/>
        <source>&amp;Toolbars</source>
        <translation>工具列(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="185"/>
        <source>Path &amp;Bar</source>
        <translation>路徑工具列 (&amp;B)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="298"/>
        <source>Go &amp;Up</source>
        <translation>上一層(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="313"/>
        <source>&amp;Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="325"/>
        <source>&amp;Reload</source>
        <translation>重新讀取(&amp;)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="337"/>
        <source>Go</source>
        <translation>到</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="346"/>
        <source>Quit</source>
        <translation>離開</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="355"/>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="364"/>
        <source>&amp;New Window</source>
        <translation>新視窗(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="367"/>
        <source>New Window</source>
        <translation>新視窗</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="370"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="378"/>
        <source>Show &amp;Hidden</source>
        <translation>顯示隱藏檔(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="381"/>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="390"/>
        <source>&amp;Computer</source>
        <translation>電腦(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="399"/>
        <source>&amp;Trash</source>
        <translation>垃圾桶(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="404"/>
        <source>&amp;Network</source>
        <translation>網路(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="413"/>
        <source>&amp;Desktop</source>
        <translation>桌面(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="422"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>加入到書籤(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="427"/>
        <source>&amp;Applications</source>
        <translation>應用程式(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="440"/>
        <source>&amp;Icon View</source>
        <translation>圖示檢視(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="448"/>
        <source>&amp;Compact View</source>
        <translation>簡易檢視(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="456"/>
        <source>&amp;Detailed List</source>
        <translation>詳細清單(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="464"/>
        <source>&amp;Thumbnail View</source>
        <translation>縮圖檢視(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="473"/>
        <source>Cu&amp;t</source>
        <translation>剪下(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="521"/>
        <source>&amp;Ascending</source>
        <translation>升冪排列(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="529"/>
        <source>&amp;Descending</source>
        <translation>降冪排列(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="537"/>
        <source>&amp;By File Name</source>
        <translation>以檔案名稱( &amp;B)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="545"/>
        <source>By &amp;Modification Time</source>
        <translation>以最後修改時間 (&amp;M)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="553"/>
        <source>By File &amp;Type</source>
        <translation>以檔案型態 (&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="561"/>
        <source>By &amp;Owner</source>
        <translation>以擁有者 (&amp;O)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="569"/>
        <source>&amp;Folder First</source>
        <translation>資料夾優先 (&amp;F)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="577"/>
        <source>&amp;Preserve sorting for this folder</source>
        <translation>保存這個目錄的排序設定</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="652"/>
        <source>C&amp;lose Tab</source>
        <translation>關閉(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="660"/>
        <source>File &amp;Properties</source>
        <translation>檔案屬性(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="668"/>
        <source>&amp;Folder Properties</source>
        <translation>資料夾屬性(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="676"/>
        <source>&amp;Case Sensitive</source>
        <translation>區分大小寫 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="684"/>
        <source>By File &amp;Size</source>
        <translation>依照檔案大小 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="689"/>
        <source>&amp;Close Window</source>
        <translation>關閉視窗 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="692"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="727"/>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="739"/>
        <source>Ctrl+Alt+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="755"/>
        <source>&amp;Filter</source>
        <translation>過濾 (&amp;F)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="758"/>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="767"/>
        <source>Close &amp;previous tabs</source>
        <translation>關閉前一個分頁 &amp;P)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="776"/>
        <source>Close &amp;next tabs</source>
        <translation>關閉下一個分頁 (&amp;N)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="815"/>
        <source>&amp;Preserve Settings for This Folder</source>
        <translation>保存這個目錄的設定</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="820"/>
        <source>Connect to &amp;Server</source>
        <translation>連線到伺服器 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="828"/>
        <source>&amp;Location</source>
        <translation>位置 (&amp;L)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="836"/>
        <source>&amp;Path Buttons</source>
        <translation>路徑按鈕 (&amp;P)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="841"/>
        <source>&amp;Bulk Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="844"/>
        <source>Bulk Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="847"/>
        <source>Ctrl+F2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="781"/>
        <source>Close &amp;other tabs</source>
        <translation>關閉其他分頁 (&amp;O)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="789"/>
        <source>&amp;Menu bar</source>
        <translation>選單列 (&amp;M)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="792"/>
        <source>Menu bar</source>
        <translation>選單列</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="795"/>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="804"/>
        <location filename="../../main-win.ui" line="807"/>
        <source>Menu</source>
        <translation>選單</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="124"/>
        <source>C&amp;reate New</source>
        <translation>新建 (&amp;R)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="152"/>
        <source>&amp;Sorting</source>
        <translation>排序(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="264"/>
        <source>Main Toolbar</source>
        <translation>主要工具列</translation>
    </message>
    <message>
        <source>Icon View</source>
        <translation type="obsolete">圖示檢視</translation>
    </message>
    <message>
        <source>Compact View</source>
        <translation type="obsolete">簡易檢視</translation>
    </message>
    <message>
        <source>Detailed List</source>
        <translation type="obsolete">詳細清單</translation>
    </message>
    <message>
        <source>Thumbnail View</source>
        <translation type="obsolete">縮圖檢視</translation>
    </message>
    <message>
        <source>&amp;Cut</source>
        <translation type="obsolete">剪下(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="476"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="485"/>
        <source>&amp;Copy</source>
        <translation>複製(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="488"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="497"/>
        <source>&amp;Paste</source>
        <translation>貼上(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="500"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="505"/>
        <source>Select &amp;All</source>
        <translation>全選(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="513"/>
        <source>Pr&amp;eferences</source>
        <translation>偏好設定(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="627"/>
        <source>&amp;Invert Selection</source>
        <translation>反向選取(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="636"/>
        <source>&amp;Delete</source>
        <translation>刪除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="644"/>
        <source>&amp;Rename</source>
        <translation>重新命名(&amp;R)</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="obsolete">全選</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="508"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">偏好設定</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="vanished">升冪排列</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="vanished">降冪排列</translation>
    </message>
    <message>
        <source>By File Name</source>
        <translation type="vanished">依照檔名</translation>
    </message>
    <message>
        <source>By Modification Time</source>
        <translation type="vanished">依照修改時間</translation>
    </message>
    <message>
        <source>By File Type</source>
        <translation type="vanished">依照檔案類型</translation>
    </message>
    <message>
        <source>By Owner</source>
        <translation type="vanished">依照檔案擁有者</translation>
    </message>
    <message>
        <source>Folder First</source>
        <translation type="vanished">資料夾優先</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="586"/>
        <source>New &amp;Tab</source>
        <translation>新分頁(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="589"/>
        <source>New Tab</source>
        <translation>新分頁</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="592"/>
        <source>Ctrl+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="601"/>
        <source>Go &amp;Back</source>
        <translation>後退(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="604"/>
        <source>Go Back</source>
        <translation>後退</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="607"/>
        <source>Alt+Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="616"/>
        <source>Go &amp;Forward</source>
        <translation>前進(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="619"/>
        <source>Go Forward</source>
        <translation>前進</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="622"/>
        <source>Alt+Right</source>
        <translation></translation>
    </message>
    <message>
        <source>Invert Selection</source>
        <translation type="obsolete">反向選取</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">刪除</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="639"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="obsolete">重新命名</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="647"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation type="obsolete">關閉分頁</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="655"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>File Properties</source>
        <translation type="obsolete">檔案屬性</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="663"/>
        <source>Alt+Return</source>
        <translation></translation>
    </message>
    <message>
        <source>Folder Properties</source>
        <translation type="obsolete">資料夾屬性</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation type="vanished">區分大小寫</translation>
    </message>
    <message>
        <source>By File Size</source>
        <translation type="vanished">依照檔案大小</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="vanished">關閉視窗</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="697"/>
        <source>Edit Bookmarks</source>
        <translation>編輯書籤</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="702"/>
        <source>Open &amp;Terminal</source>
        <translation>開啟終端機(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="705"/>
        <source>F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="710"/>
        <source>Open as &amp;Root</source>
        <translation>以系統管理員權限開啟(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="715"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>編輯書籤(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="724"/>
        <source>&amp;Folder</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="736"/>
        <source>&amp;Blank File</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="744"/>
        <source>&amp;Find Files</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="747"/>
        <source>F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="93"/>
        <source>Filter by string...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="120"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="142"/>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="148"/>
        <location filename="../../main-win.ui" line="168"/>
        <source>&amp;View</source>
        <translation>檢視(&amp;V)</translation>
    </message>
    <message>
        <source>Sorting</source>
        <translation type="obsolete">排序</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="202"/>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="220"/>
        <source>&amp;Bookmarks</source>
        <translation>書籤(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="227"/>
        <source>&amp;Go</source>
        <translation>前往(&amp;G)</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="244"/>
        <source>&amp;Tool</source>
        <translation>工具(&amp;T)</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../../application.cpp" line="169"/>
        <source>Name of configuration profile</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="169"/>
        <source>PROFILE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="172"/>
        <source>Run PCManFM as a daemon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="175"/>
        <source>Quit PCManFM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="178"/>
        <source>Launch desktop manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="181"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="184"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="184"/>
        <location filename="../../application.cpp" line="199"/>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="187"/>
        <source>Open new window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="190"/>
        <source>Open Find Files utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="193"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="193"/>
        <source>FILE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="196"/>
        <source>MODE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="196"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="199"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="202"/>
        <source>Files or directories to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="202"/>
        <source>[FILE1, FILE2,...]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="541"/>
        <location filename="../../application.cpp" line="546"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="546"/>
        <source>Terminal emulator is not set.</source>
        <translation>終端機模擬器尚未設定</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../../autorundialog.cpp" line="44"/>
        <source>Open in file manager</source>
        <translation>在檔案管理程式內開啟</translation>
    </message>
    <message>
        <location filename="../../autorundialog.cpp" line="135"/>
        <source>Removable Disk</source>
        <translation>可移除式磁碟</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="52"/>
        <source>Fill with background color only</source>
        <translation>只以背景色填滿</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="53"/>
        <source>Stretch to fill the entire screen</source>
        <translation>延展以填滿整個螢幕</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="54"/>
        <source>Stretch to fit the screen</source>
        <translation>延展到最適合螢幕大小</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="55"/>
        <source>Center on the screen</source>
        <translation>置於螢幕中央</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="56"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>連續拼貼鋪滿整個螢幕</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="57"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation>縮放影像填滿整個螢幕</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="204"/>
        <source>Image Files</source>
        <translation>影像檔案</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../../desktopwindow.cpp" line="548"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>保持在目前位置(&amp;K)</translation>
    </message>
    <message>
        <location filename="../../desktopwindow.cpp" line="574"/>
        <source>Hide Desktop Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktopwindow.cpp" line="579"/>
        <source>Desktop Preferences</source>
        <translation>桌面偏好設定</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="275"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>清除文字(Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="365"/>
        <source>Hide menu bar</source>
        <translation>隱藏選單列</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="366"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation>選單列將完全被隱藏，使用 Ctrl+M 可再次顯示。</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="651"/>
        <source>Version: %1</source>
        <translation>版本: %1</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1360"/>
        <source>&amp;Move to Trash</source>
        <translation>移動到垃圾桶(&amp;M)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1360"/>
        <source>&amp;Delete</source>
        <translation>刪除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1429"/>
        <location filename="../../mainwindow.cpp" line="1437"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1437"/>
        <source>Switch user command is not set.</source>
        <translation>切換使用者指令尚未設定</translation>
    </message>
    <message>
        <source>Terminal emulator is not set.</source>
        <translation type="obsolete">終端機模擬器尚未設定</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.cpp" line="194"/>
        <source>Icon View</source>
        <translation>圖示檢視</translation>
    </message>
    <message>
        <source>Compact Icon View</source>
        <translation type="vanished">簡易檢視</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="195"/>
        <source>Compact View</source>
        <translation>簡易檢視</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="196"/>
        <source>Thumbnail View</source>
        <translation>縮圖檢視</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="197"/>
        <source>Detailed List View</source>
        <translation>詳細清單檢視</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../../tabpage.cpp" line="254"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../../tabpage.cpp" line="267"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>可用空間 %1 (全部: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="284"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n 個項目</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="286"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n 個隱藏)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../../tabpage.cpp" line="291"/>
        <location filename="../../tabpage.cpp" line="468"/>
        <location filename="../../tabpage.cpp" line="484"/>
        <source>Link to</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="498"/>
        <source>%n item(s) selected</source>
        <translation>
            <numerusform>選取 %n 個項目</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 item(s) selected</source>
        <translation type="vanished">選取 %1 個項目</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../../view.cpp" line="102"/>
        <source>Open in New T&amp;ab</source>
        <translation>在新分頁開啟 (&amp;A)</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="106"/>
        <source>Open in New Win&amp;dow</source>
        <translation>在新視窗開啟 (&amp;D)</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>在終端機內開啟 (&amp;L)</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>偏好設定</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>使用者界面</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>行為</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="40"/>
        <source>Display</source>
        <translation>顯示</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="50"/>
        <location filename="../../preferences.ui" line="643"/>
        <source>Thumbnail</source>
        <translation>縮圖</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>磁碟</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>進階</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="130"/>
        <source>Bookmarks:</source>
        <translation>書籤:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="138"/>
        <source>Open in current tab</source>
        <translation>在目前分頁開啟</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="143"/>
        <source>Open in new tab</source>
        <translation>在新分頁開啟</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="148"/>
        <source>Open in new window</source>
        <translation>在新視窗開啟</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="179"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>在可移除裝置上直接刪除檔案，而不移到垃圾桶</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="186"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>將檔案移到垃圾桶前先確認</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="193"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation>開啟可執行檔案時不要提問</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="220"/>
        <source>Icons</source>
        <translation>圖示</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="252"/>
        <source>Size of big icons:</source>
        <translation>大圖示尺寸:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="269"/>
        <source>Size of small icons:</source>
        <translation>小圖示尺寸:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="286"/>
        <source>Size of thumbnails:</source>
        <translation>縮圖尺寸:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="300"/>
        <source>Size of side pane icons:</source>
        <translation>側邊欄圖示尺寸:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="232"/>
        <source>Icon theme:</source>
        <translation>圖示佈景主題:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="456"/>
        <source>Window</source>
        <translation>視窗</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="501"/>
        <source>Default width of new windows:</source>
        <translation>新視窗的預設寬度</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="515"/>
        <source>Default height of new windows:</source>
        <translation>新視窗的預設高度</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="469"/>
        <source>Always show the tab bar</source>
        <translation>總是顯示標籤列</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="487"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>在分頁標籤上顯示「關閉」按鈕</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="494"/>
        <source>Remember the size of the last closed window</source>
        <translation>記住最後關閉視窗的大小</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="90"/>
        <source>Open files with single click</source>
        <translation>單擊開啟檔案</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="100"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>滑鼠單擊模式下自動選取的時間延遲 (0 表示關閉)</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="107"/>
        <source>Default view mode:</source>
        <translation>預設檢視模式:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="120"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="159"/>
        <source>File Operations</source>
        <translation>檔案操作</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="165"/>
        <source>Confirm before deleting files</source>
        <translation>刪除檔案前確認</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="172"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>將檔案移動到垃圾桶，而不直接刪除</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="249"/>
        <location filename="../../preferences.ui" line="259"/>
        <source>Used by Icon View</source>
        <translation>由圖示檢視使用</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="266"/>
        <location filename="../../preferences.ui" line="276"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation>由簡易檢視和詳細清單列表使用</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="283"/>
        <location filename="../../preferences.ui" line="293"/>
        <source>Used by Thumbnail View</source>
        <translation>縮圖檢視使用</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="313"/>
        <source>User interface</source>
        <translation>使用者界面</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="326"/>
        <source>Treat backup files as hidden</source>
        <translation>將備份檔案視為隱藏檔</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="336"/>
        <source>Always show full file names</source>
        <translation>總是顯示完整檔案名稱</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="346"/>
        <source>Show icons of hidden files shadowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="369"/>
        <source>Minimum item margins in icon view:</source>
        <translation>圖示檢視項目邊緣留空</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="376"/>
        <source>3 px by default.</source>
        <translation>預設 3 像素</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="379"/>
        <location filename="../../preferences.ui" line="403"/>
        <source> px</source>
        <translation> 像素 </translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="392"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="399"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="416"/>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="465"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation>若取消，分頁工具列只會在有多於一個分頁的時候顯示</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="476"/>
        <source>If unchecked, the tab bar will be positioned only
above the folder-view and not above the left pane.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="480"/>
        <source>Fullwidth tab bar</source>
        <translation>完整寬度的分頁工具列</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="532"/>
        <source>Show in places</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="539"/>
        <source>Home</source>
        <translation>家目錄</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="552"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="565"/>
        <source>Trash can</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="578"/>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="591"/>
        <source>Applications</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="599"/>
        <source>Devices</source>
        <translation>裝置</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="607"/>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="673"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation>需要 ffmpegthumbnailer</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="676"/>
        <source>Show thumbnails of files</source>
        <translation>顯示檔案縮圖</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="836"/>
        <source>Templates</source>
        <translation>模板</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="842"/>
        <source>Show only user defined templates in menu</source>
        <translation>選單中只顯示使用者定義的範本</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="849"/>
        <source>Show only one template for each MIME type</source>
        <translation>每個 MIME 型態只顯示一個範本</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="856"/>
        <source>Run default application after creation from template</source>
        <translation>建立檔案範本之後執行預設程式開啟</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="666"/>
        <source>Only show thumbnails for local files</source>
        <translation>只顯示本地檔案的縮圖</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="649"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>不為超過指定大小的檔案產生縮圖:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="656"/>
        <source> KB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="733"/>
        <source>When removable medium unmounted:</source>
        <translation type="unfinished">當卸載可移除裝置時:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="789"/>
        <source>Switch &amp;user command:</source>
        <translation>切換使用者的指令:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="813"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>壓縮程式整合:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="782"/>
        <source>Terminal emulator:</source>
        <translation>終端機模擬器:</translation>
    </message>
    <message>
        <source>Do not generate thumbnails for files exceeding this size (KB):</source>
        <translation type="obsolete">不為超過指定大小的檔案產生縮圖 (KB)</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="703"/>
        <source>Auto Mount</source>
        <translation>自動掛載</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="709"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>掛載可掛載的磁碟</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="716"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>可移除式媒體插入時自動掛載</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="723"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>可移除式媒體插入時顯示可用的選項</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="739"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>關閉顯示可移除裝置的分頁</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="746"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>將分頁內容改為家目錄</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="773"/>
        <source>Programs</source>
        <translation>程式</translation>
    </message>
    <message>
        <source>Terminal emulator command for directories:</source>
        <translation type="obsolete">用來開啟目錄的終端機模擬器指令:</translation>
    </message>
    <message>
        <source>Switch user command:</source>
        <translation type="vanished">切換使用者的指令:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="802"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>範例: 終端機指令可用 &quot;xterm -e %s&quot;而切換使用者指令可用 &quot;gksu %s&quot;。
%s = 想要用終端機或是切換使用者執行的指令。</translation>
    </message>
    <message>
        <source>Archiver integration:</source>
        <translation type="vanished">壓縮程式整合:</translation>
    </message>
    <message>
        <source>Terminal emulator command for programs:</source>
        <translation type="obsolete">用來執行程式的終端機模擬器指令:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="319"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../bulkrename.cpp" line="72"/>
        <source>Renaming files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../bulkrename.cpp" line="72"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../bulkrename.cpp" line="79"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../bulkrename.cpp" line="79"/>
        <source>Renaming is aborted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../bulkrename.cpp" line="92"/>
        <location filename="../../bulkrename.cpp" line="95"/>
        <source>Error</source>
        <translation type="unfinished">錯誤</translation>
    </message>
    <message>
        <location filename="../../bulkrename.cpp" line="92"/>
        <source>No file could be renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../bulkrename.cpp" line="95"/>
        <source>Some files could not be renamed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
